elephant.test.make_spike_extraction_test_data module — Elephant 0.5.0 documentation

Elephant 0.5

- Pages
  - Overview
  - Prerequisites / Installation
  - Tutorials
  - Function Reference by Module
  - Developers’ guide
  - Documentation and style guideline
  - Authors and contributors
  - Release Notes
- This Page
  - elephant.test.make_spike_extraction_test_data module

# elephant.test.make_spike_extraction_test_data module

`elephant.test.make_spike_extraction_test_data.` `main`()